@@ -63,6 +63,8 @@ void pacrunner_proxy_unref(struct pacrunner_proxy *proxy);
 const char *pacrunner_proxy_get_interface(struct pacrunner_proxy *proxy);
 const char *pacrunner_proxy_get_script(struct pacrunner_proxy *proxy);
 
+int pacrunner_proxy_set_domains(struct pacrunner_proxy *proxy,
+					char **domains, gboolean browser_only);
 int pacrunner_proxy_set_direct(struct pacrunner_proxy *proxy);
 int pacrunner_proxy_set_manual(struct pacrunner_proxy *proxy,
 					char **servers, char **excludes);
@@ -74,6 +76,9 @@ int pacrunner_proxy_disable(struct pacrunner_proxy *proxy);
 
 char *pacrunner_proxy_lookup(const char *url, const char *host);
 
+void __pacrunner_proxy_set_jsctx(struct pacrunner_proxy *proxy, void *jsctx);
+void *__pacrunner_proxy_get_jsctx(struct pacrunner_proxy *proxy);
+
 int __pacrunner_proxy_init(void);
 void __pacrunner_proxy_cleanup(void);
 
@@ -108,4 +113,6 @@ char *__pacrunner_mozjs_execute(const char *url, const char *host);
 int __pacrunner_js_init(void);
 void __pacrunner_js_cleanup(void);
 int __pacrunner_js_set_proxy(struct pacrunner_proxy *proxy);
-char *__pacrunner_js_execute(const char *url, const char *host);
+int __pacrunner_js_clear_proxy(struct pacrunner_proxy *proxy);
+char *__pacrunner_js_execute(struct pacrunner_proxy *proxy, const char *url,
+			     const char *host);
